@@ -149,6 +149,9 @@ runDataTypeTests <- function(db, redshift=FALSE) {
       attr(res$updated_at, "tzone") <- Sys.timezone()
     }
 
+    # for R-devel
+    attr(events$updated_at, "tzone") <- Sys.timezone()
+
     expect_equal(res$updated_at, events$updated_at)
 
     # test stored time
@@ -164,6 +167,9 @@ runDataTypeTests <- function(db, redshift=FALSE) {
     events <- data.frame(deleted_at=c(t1, t2))
     dbxInsert(db, "events", events)
 
+    # for R-devel
+    attr(events$deleted_at, "tzone") <- Sys.timezone()
+
     # test returned time
     res <- dbxSelect(db, "SELECT * FROM events ORDER BY id")
     expect_equal(res$deleted_at, events$deleted_at)
